package io.xjar.jar;

import io.xjar.XConstants;
import io.xjar.XLauncher;
import io.xjar.jar.XJarClassLoader;
import java.io.File;
import java.lang.reflect.Method;
import java.net.URI;
import java.net.URL;
import java.net.URLClassLoader;
import java.security.CodeSource;
import java.security.ProtectionDomain;
import java.util.jar.Attributes;
import java.util.jar.JarFile;
import java.util.jar.Manifest;

public class XJarLauncher implements XConstants {

   private final XLauncher xLauncher;


   public XJarLauncher(String ... args) throws Exception {
      this.xLauncher = new XLauncher(args);
   }

   public static void main(String ... args) throws Exception {
      (new XJarLauncher(args)).launch();
   }

   public void launch() throws Exception {
      ClassLoader classLoader = this.getClass().getClassLoader();
      XJarClassLoader xJarClassLoader;
      CodeSource source;
      URI location;
      String filepath;
      File file;
      ProtectionDomain domain1;
      if(classLoader instanceof URLClassLoader) {
         URLClassLoader domain = (URLClassLoader)classLoader;
         xJarClassLoader = new XJarClassLoader(domain.getURLs(), classLoader.getParent(), this.xLauncher.xDecryptor, this.xLauncher.xEncryptor, this.xLauncher.xKey);
      } else {
         domain1 = this.getClass().getProtectionDomain();
         source = domain1.getCodeSource();
         location = source == null?null:source.getLocation().toURI();
         filepath = location == null?null:location.getSchemeSpecificPart();
         if(filepath == null) {
            throw new IllegalStateException("Unable to determine code source archive");
         }

         file = new File(filepath);
         URL jar = file.toURI().toURL();
         xJarClassLoader = new XJarClassLoader(new URL[]{jar}, classLoader.getParent(), this.xLauncher.xDecryptor, this.xLauncher.xEncryptor, this.xLauncher.xKey);
      }

      Thread.currentThread().setContextClassLoader(xJarClassLoader);
      domain1 = this.getClass().getProtectionDomain();
      source = domain1.getCodeSource();
      location = source.getLocation().toURI();
      filepath = location.getSchemeSpecificPart();
      file = new File(filepath);
      JarFile jar1 = new JarFile(file, false);
      Manifest manifest = jar1.getManifest();
      Attributes attributes = manifest.getMainAttributes();
      String jarMainClass = attributes.getValue("Jar-Main-Class");
      Class mainClass = xJarClassLoader.loadClass(jarMainClass);
      Method mainMethod = mainClass.getMethod("main", new Class[]{String[].class});
      mainMethod.invoke((Object)null, new Object[]{this.xLauncher.args});
   }
}
